@@ -388,7 +388,7 @@ rsaga.get.version = function(env = rsaga.env(version=NA), ...)
     # Added 27-Dec-2011:
     # saga_cmd --version (only works in SAGA GIS 2.0.8+)
     out = rsaga.geoprocessor(lib = NULL, prefix = "--version", show.output.on.console = FALSE,
-        flags = NULL, warn = -1, env = env, ...)
+        flags = NULL, warn = -1, env = env, check.parameters = FALSE, ...)
     if (all(out != "error: module library not found [--version]")) {
         if (length(out >= 1)) {
             if (any(sel <- (substr(out,1,9) == "SAGA API:"))) {
@@ -414,7 +414,7 @@ rsaga.get.version = function(env = rsaga.env(version=NA), ...)
     #### check if this function works on unix????
     # Retrieve basic help page of saga_cmd:
     out = rsaga.geoprocessor(lib = NULL, prefix = "-h", show.output.on.console = FALSE,
-        flags = NULL, warn = -1, env = env, ...)
+        flags = NULL, warn = -1, env = env, check.parameters = FALSE, ...)
 
     # Process the help page line by line in order to find lines starting
     # with "SAGA API " (or "SAGA CMD ", if no "SAGA API " line available)
@@ -535,7 +535,7 @@ rsaga.get.lib.modules = function(lib, env=rsaga.env(), interactive=FALSE)
 
     rawres = rsaga.geoprocessor(lib, module=NULL, env=env,
         intern=TRUE, show.output.on.console=FALSE, flags=NULL, invisible=TRUE,
-        reduce.intern=FALSE, check.module.exists=FALSE, warn = -1)
+        reduce.intern=FALSE, check.module.exists=FALSE, check.parameters = FALSE, warn = -1)
 
     wh = which( gsub(" ","",tolower(rawres)) %in% c("availablemodules:","executablemodules:","modules:", "tools:") )
 
@@ -711,7 +711,7 @@ rsaga.get.usage = function(lib, module, env=rsaga.env(), show=TRUE)
 
     usage = rsaga.geoprocessor(lib, module, param = list(h=""), env = env,
         intern = TRUE, show.output.on.console = FALSE, flags = NULL,
-        check.module.exists = FALSE, warn = -1)
+        check.module.exists = FALSE, check.parameters = FALSE, warn = -1)
 
     skip = 0
     while ((length(usage)>(1+skip)) & (substr(usage[1+skip],1,6)!="Usage:")) {
@@ -814,7 +814,7 @@ rsaga.html.help = function(lib, module=NULL, use.program.folder = TRUE, env=rsag
         # Create help files in the SAGA GIS program folder if they don't yet exist:
         if (!file.exists(fnm)) {
             cat("Calling SAGA GIS to create documentation files in the program folder...\n")
-            rsaga.geoprocessor(lib = NULL, module = NULL, prefix = "-d", env = env)
+            rsaga.geoprocessor(lib = NULL, module = NULL, prefix = "-d", env = env, check.parameters = FALSE)
         }
 
         # Issue a warning if documentation file still can't be accessed:
@@ -857,6 +857,9 @@ rsaga.html.help = function(lib, module=NULL, use.program.folder = TRUE, env=rsag
 #' @param check.module.exists logical (default: `TRUE`): call [rsaga.module.exists()] to determine if the specified module can be called in the current SAGA installation
 #' @param warn logical (default: `TRUE`): for internal purposes - can be used to suppress warning messages generated by failed SAGA_CMD calls; currently used by [rsaga.get.lib.modules()] and related functions; see [options()] argument `warn` for details
 #' @param argsep character (default: `" "`; currently for internal use): defines the character symbol used as a separator between each argument name and argument value passed to `saga_cmd`. SAGA GIS 2.1.0 (RC1) seems to move toward `"="` as a separator, but `" "` still works and some modules (e.g. the used by `rsaga.pisr`) don't seem to work with `argsep="="`. Future releases of RSAGA may change the default `argsep` value and/or delete or ignore this argument and/or move it to [rsaga.env()].
+#'
+#' @param check.parameters logical(default: `TRUE`): Check if correct parameters are used.
+#'
 #' @param ... Additional arguments to be passed to [base::system()].
 #'
 #' @details This workhorse function establishes the interface between the SAGA command line program and R by submitting a system call. This is a low-level function that may be used for directly accessing SAGA; specific functions such as `rsaga.hillshade` are intended to be more user-friendly interfaces to the most frequently used SAGA modules. These higher-level interfaces support default values for the arguments and perform some error checking; they should therefore be preferred if available.
@@ -893,13 +896,14 @@ rsaga.html.help = function(lib, module=NULL, use.program.folder = TRUE, env=rsag
 #' }
 #' @keywords spatial interface
 #' @export
+#' @importFrom magrittr "%>%"
 rsaga.geoprocessor = function(
     lib, module = NULL, param = list(),
     show.output.on.console = TRUE, invisible = TRUE, intern = TRUE,
     prefix = NULL, flags = ifelse(show.output.on.console,"q","s"), cores,
     env = rsaga.env(), display.command = FALSE, reduce.intern = TRUE,
     check.module.exists = TRUE, warn = options("warn")$warn,
-    argsep = " ", ... )
+    argsep = " ", check.parameters = TRUE, ... )
 {
 # Issue warning if using SAGA GIS version that has not been tested with RSAGA:
     if (!is.null(env$version)) {
@@ -908,7 +912,7 @@ rsaga.geoprocessor = function(
                        "2.1.0","2.1.1","2.1.2","2.1.3","2.1.4",
                        "2.2.0","2.2.1","2.2.2","2.2.3", "2.3.1",
                        "2.3.2", "3.0.0", "4.0.0", "4.0.1", "4.1.0",
-                       "5.0.0", "6.0.0", "6.1.0", "6.2.0", "6.3.0", "6.4.0", NULL) == env$version))
+                       "5.0.0", "6.0.0", "6.1.0", "6.2.0", "6.3.0", "6.4.0", "7.0.0", NULL) == env$version))
                 warning("This RSAGA version has been tested with SAGA GIS versions 2.3.1 - 6.3.0.\n",
                     "You seem to be using SAGA GIS ", env$version, ", which may cause problems due to\n",
                     "changes in names and definitions of SAGA module arguments, etc.", sep = "" )
@@ -988,6 +992,38 @@ rsaga.geoprocessor = function(
             }
         }
 
+        # Check parameters
+        if(check.parameters) {
+          # Get console output
+          # Warning is intentionally generated
+          res <- suppressWarnings(
+            system(paste0(command, " \"", module, "\""), intern = TRUE))
+
+          # Get parameters
+          i <- grep("Usage:", res)
+
+          # Extract parameter list
+          param_list <-
+            unlist(stringr::str_extract_all(res[i], "\\[(.*?)\\]")) %>%
+            stringr::str_remove("\\[-") %>%
+            stringr::str_remove("\\]") %>%
+            stringr::str_remove("<(.*?)>") %>%
+            stringr::str_remove("\\s")
+
+          # Print error message
+          if(!all(names(param) %in% param_list)) {
+            #Get false parameter names
+            false_parameters <- names(param) %in% param_list
+            # Get all paramter names
+            paramters <- names(param)
+            stop(paste0("Wrong paramters used: ",
+                        paste(paramters[!false_parameters], collapse = " "),
+                        ". ",
+                        "Possible parameters:",
+                        paste(param_list, collapse = " ")))
+          }
+        }
+
         if (is.character(module)) module = shQuote(module)
         command = paste(command, module)
         if (length(param)>0) {
